<!DOCTYPE kpartgui>
<kpartplugin name="rellinks" library="librellinksplugin" version="3">
<MenuBar>
 <Menu name="tools"><Text>&amp;Tools</Text>
  <Menu name="rellinksMenu"><Text>Document Relations</Text>
    <Action name="rellinks_top"/>
    <Action name="rellinks_up"/>
    <Action name="rellinks_first"/>
    <Action name="rellinks_previous"/>
    <Action name="rellinks_next"/>
    <Action name="rellinks_last"/>
    <Action name="rellinks_search"/>
    <Action name="rellinks_document"/>
    <Action name="rellinks_more"/>
    <Action name="rellinks_links"/>
  </Menu>
 </Menu>
</MenuBar>


<ToolBar name="rellinksToolBar" hidden="true"><Text>Document Relations</Text>
	<Action name="rellinks_top"/>
	<Action name="rellinks_up"/>
	<Action name="rellinks_first"/>
	<Action name="rellinks_previous"/>
	<Action name="rellinks_next"/>
	<Action name="rellinks_last"/>
	<Action name="rellinks_search"/>
	<Separator  />
	<Action name="rellinks_document"/>
	<Separator  />
	<Action name="rellinks_more"/>
	<Separator  />
    <Action name="rellinks_links"/>	
</ToolBar>


</kpartplugin>
