<!DOCTYPE kpartplugin>
<kpartplugin name="DirFilter" library="libdirfilterplugin" version = "4">
<MenuBar>
 <Menu name="tools"><Text>&amp;Tools</Text>
  <Action name="filterdir"/>
 </Menu>
</MenuBar>
<ToolBar name="extraToolBar"><text>Extra Toolbar</text>
  <Action name="filterdir"/>
</ToolBar>
<ToolBar fullWidth="true" name="locationToolBar" newline="true"><text>Filter Toolbar</text>
</ToolBar>
</kpartplugin>
