<!DOCTYPE kpartgui>
<kpartplugin name="katesnippets" library="katesnippetsplugin" version="1">
<MenuBar>
 <Menu name="tools"><Text>&amp;Tools</Text>
  <Action name="edit_insert_katesnippets"/>
 </Menu>
</MenuBar>
<ToolBar name="extraToolBar">
  <Action name="edit_insert_katesnippets"/>
</ToolBar>
</kpartplugin>
