<!DOCTYPE kpartgui>
<kpartplugin name="validators" library="libvalidatorsplugin">
<MenuBar>
 <Menu name="tools"><Text>&amp;Tools</Text>
  <Action name="validateWebpage"/>
 </Menu>
</MenuBar>
<ToolBar name="extraToolBar"><text>Extra Toolbar</text>
  <Action name="validateWebpage"/>
</ToolBar>
</kpartplugin>
